@@ -29,11 +29,9 @@ describe 'basic manila' do
 
       # Manila resources
       class { '::manila':
-        sql_connection      => 'mysql+pymysql://manila:a_big_secret@127.0.0.1/manila?charset=utf8',
-        rabbit_userid       => 'manila',
-        rabbit_password     => 'an_even_bigger_secret',
-        rabbit_host         => '127.0.0.1',
-        debug               => true,
+        default_transport_url => 'rabbit://manila:an_even_bigger_secret@127.0.0.1:5672/',
+        sql_connection        => 'mysql+pymysql://manila:a_big_secret@127.0.0.1/manila?charset=utf8',
+        debug                 => true,
       }
       class { '::manila::db::mysql':
         password => 'a_big_secret',
@@ -52,6 +50,10 @@ describe 'basic manila' do
       class { '::manila::api': }
       class { '::manila::scheduler': }
 
+      # NFS-Ganesha backend. Currently this feature is only for RHEL systems
+      # because Debian/Ubuntu systems do not have nfs-ganesha package yet.
+      class { '::manila::ganesha': }
+
       # missing: backends, share, service_instance
       EOS
 
